/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {ClayButtonWithIcon} from '@clayui/button';
import ClayDropDown from '@clayui/drop-down';
import ClayIcon from '@clayui/icon';
import React, {useContext, useState} from 'react';

import {AppContext} from '../../AppContext';
import DataSetContext from '../../DataSetContext';
import persistActiveView from '../../thunks/persistActiveView';
import ViewsContext from '../../views/ViewsContext';

function ActiveViewSelector({views}) {
	const {appURL, portletId} = useContext(AppContext);
	const [active, setActive] = useState(false);
	const [{activeView}, dispatch] = useContext(ViewsContext);
	const {id} = useContext(DataSetContext);

	return (
		<ClayDropDown
			active={active}
			onActiveChange={setActive}
			trigger={
				<ClayButtonWithIcon
					className="nav-link nav-link-monospaced"
					displayType="unstyled"
					symbol={activeView.thumbnail}
				/>
			}
		>
			<ClayDropDown.ItemList>
				{views.map(({label, name, thumbnail}) => (
					<ClayDropDown.Item
						key={name}
						onClick={(event) => {
							event.preventDefault();
							setActive(false);
							dispatch(
								persistActiveView({
									activeViewName: name,
									appURL,
									id,
									portletId,
								})
							);
						}}
					>
						<ClayIcon className="mr-3" symbol={thumbnail} />

						{label}
					</ClayDropDown.Item>
				))}
			</ClayDropDown.ItemList>
		</ClayDropDown>
	);
}

export default ActiveViewSelector;
