/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayDropDown from '@clayui/drop-down';
import ClayIcon from '@clayui/icon';
import ClayLabel from '@clayui/label';
import classNames from 'classnames';
import PropTypes from 'prop-types';
import React, {useState} from 'react';

import {Filter} from './filters/index';

function FilterResume(props) {
	const [open, setOpen] = useState(false);

	const label = (
		<ClayLabel
			className={classNames(
				'filter-resume component-label tbar-label mr-2',
				props.disabled && 'disabled',
				open && 'active'
			)}
			closeButtonProps={{
				className: 'filter-resume-close',
				disabled: props.disabled,
				onClick: () => props.updateFilterState(props.id),
			}}
			role="button"
		>
			<div className="filter-resume-content">
				<ClayIcon
					className="mr-2"
					symbol={open ? 'caret-top' : 'caret-bottom'}
				/>

				<div className="label-section">
					{props.label}: {props.formattedValue}
				</div>
			</div>
		</ClayLabel>
	);

	const dropDown = (
		<ClayDropDown
			active={open}
			className="d-inline-flex"
			onActiveChange={setOpen}
			trigger={label}
		>
			<li className="dropdown-subheader">{props.label}</li>

			<Filter {...props} />
		</ClayDropDown>
	);

	return props.disabled ? label : dropDown;
}

FilterResume.propTypes = {
	disabled: PropTypes.bool,
	formattedValue: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
	id: PropTypes.string,
	label: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
};

export default FilterResume;
