/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {ClayButtonWithIcon} from '@clayui/button';
import {ClayInput} from '@clayui/form';
import React, {useContext, useEffect, useState} from 'react';

import DataSetContext from '../../DataSetContext';

function MainSearch({setShowMobile}) {
	const {searchParam, updateSearchParam} = useContext(DataSetContext);

	const [inputValue, setInputValue] = useState(searchParam);

	useEffect(() => {
		setInputValue(searchParam || '');
	}, [searchParam]);

	function handleKeyDown(event) {
		if (event.key === 'Enter') {
			event.preventDefault();

			return updateSearchParam(inputValue);
		}
	}

	return (
		<ClayInput.Group>
			<ClayInput.GroupItem>
				<ClayInput
					aria-label={Liferay.Language.get('search')}
					className="input-group-inset input-group-inset-after"
					onChange={(event) => setInputValue(event.target.value)}
					onKeyDown={handleKeyDown}
					placeholder={Liferay.Language.get('search')}
					value={inputValue}
				/>

				<ClayInput.GroupInsetItem after tag="div">
					<ClayButtonWithIcon
						aria-label={Liferay.Language.get('clear')}
						className="navbar-breakpoint-d-none"
						disabled={!inputValue.length}
						displayType="unstyled"
						monospaced={false}
						onClick={(event) => {
							event.preventDefault();

							setInputValue('');
							setShowMobile(false);

							updateSearchParam('');
						}}
						style={{
							opacity: !inputValue.length ? 0 : 1,
							pointerEvents: !inputValue.length ? 'none' : 'auto',
						}}
						symbol="times-circle"
					/>

					<ClayButtonWithIcon
						aria-label={Liferay.Language.get('search')}
						displayType="unstyled"
						monospaced={false}
						onClick={(event) => {
							event.preventDefault();

							updateSearchParam(inputValue);
						}}
						symbol="search"
						type="submit"
					/>
				</ClayInput.GroupInsetItem>
			</ClayInput.GroupItem>
		</ClayInput.Group>
	);
}

export default MainSearch;
